pub struct SimpleBarStyle(/* private fields */);Expand description
W Progress view style that is only the progress bar, no message text.
Implementations
Sourceimpl SimpleBarStyle
impl SimpleBarStyle
Sourcepub fn widget_new() -> Self
pub fn widget_new() -> Self
Start building a new instance.
Sourcepub fn widget_type() -> WidgetType
pub fn widget_type() -> WidgetType
Gets the widget type info.
Methods from Deref<Target = DefaultStyle>
Sourcepub fn collapse_complete(&self, collapse: impl IntoVar<bool>)
pub fn collapse_complete(&self, collapse: impl IntoVar<bool>)
P Collapse visibility when Progress::is_complete.
Sourcepub fn is_indeterminate(&self, state: impl IntoVar<bool>)
pub fn is_indeterminate(&self, state: impl IntoVar<bool>)
P Getter property that is true when progress is indeterminate.
This event works in any context that sets PROGRESS_VAR.
Methods from Deref<Target = Style>
Sourcepub fn widget_build(&mut self) -> StyleBuilder
pub fn widget_build(&mut self) -> StyleBuilder
Build the style.
Sourcepub fn replace(&self, replace: impl IntoValue<bool>)
pub fn replace(&self, replace: impl IntoValue<bool>)
B Fully replace the contextual style.
This is not enabled by default, if set to true the contextual style properties are removed.
Sourcepub fn named_style_fn(&self, name: impl IntoValue<NamedStyleVar>)
pub fn named_style_fn(&self, name: impl IntoValue<NamedStyleVar>)
B Set in the default properties of a named style to define the contextual variable for that style.
During widget instantiation, if this is set by default in a style the contextual style is used as the defaults and only the properties set on the style instance replace them.
This property is part of the named styles pattern, see impl_named_style_fn! for more details.
Note that this property expects a ContextVar<StyleFn> as a value, not a variable directly, it will also only work if
set in the default properties of a style type.